{namespace neos=TYPO3\Neos\ViewHelpers}
<div class="loader">
	<div class="spinner">
		<div class="double-bounce1"></div>
		<div class="double-bounce2"></div>
	</div>
</div>

<div class="nav-container">
	{parts.navigation -> f:format.raw()}
</div>

<div class="main-container">
	{content.main -> f:format.raw()}
</div>

<div class="footer-container">
	{parts.footer -> f:format.raw()}
</div>

<script src="https://www.youtube.com/iframe_api"></script>
<script src="{f:uri.resource(path: 'js/jquery.min.js', package: 'MOC.Pivot')}"></script>
<script src="{f:uri.resource(path: 'js/jquery.plugin.min.js', package: 'MOC.Pivot')}"></script>
<script src="{f:uri.resource(path: 'js/bootstrap.min.js', package: 'MOC.Pivot')}"></script>
<script src="{f:uri.resource(path: 'js/jquery.flexslider-min.js', package: 'MOC.Pivot')}"></script>
<script src="{f:uri.resource(path: 'js/smooth-scroll.min.js', package: 'MOC.Pivot')}"></script>
<script src="{f:uri.resource(path: 'js/skrollr.min.js', package: 'MOC.Pivot')}"></script>
<script src="{f:uri.resource(path: 'js/spectragram.min.js', package: 'MOC.Pivot')}"></script>
<script src="{f:uri.resource(path: 'js/scrollReveal.min.js', package: 'MOC.Pivot')}"></script>
<script src="{f:uri.resource(path: 'js/isotope.min.js', package: 'MOC.Pivot')}"></script>
<script src="{f:uri.resource(path: 'js/twitterFetcher_v10_min.js', package: 'MOC.Pivot')}"></script>
<script src="{f:uri.resource(path: 'js/lightbox.min.js', package: 'MOC.Pivot')}"></script>
<script src="{f:uri.resource(path: 'js/jquery.countdown.min.js', package: 'MOC.Pivot')}"></script>
<script src="{f:uri.resource(path: 'js/scripts.js', package: 'MOC.Pivot')}"></script>
<script src="{f:uri.resource(path: 'js/custom.js', package: 'MOC.Pivot')}"></script>
<script type='text/javascript' src='//s3.amazonaws.com/downloads.mailchimp.com/js/mc-validate.js'></script>
<script type='text/javascript'>(function ($) {
	window.fnames = new Array();
	window.ftypes = new Array();
	fnames[0] = 'EMAIL';
	ftypes[0] = 'email';
	fnames[1] = 'FNAME';
	ftypes[1] = 'text';
	fnames[2] = 'LNAME';
	ftypes[2] = 'text';
	/*
	 * Translated default messages for the $ validation plugin.
	 * Locale: DA
	 */
	$.extend($.validator.messages, {
		required: "Dette felt er påkrævet.",
		maxlength: $.validator.format("Indtast højst {0} tegn."),
		minlength: $.validator.format("Indtast mindst {0} tegn."),
		rangelength: $.validator.format("Indtast mindst {0} og højst {1} tegn."),
		email: "Indtast en gyldig email-adresse.",
		url: "Indtast en gyldig URL.",
		date: "Indtast en gyldig dato.",
		number: "Indtast et tal.",
		digits: "Indtast kun cifre.",
		equalTo: "Indtast den samme værdi igen.",
		range: $.validator.format("Angiv en værdi mellem {0} og {1}."),
		max: $.validator.format("Angiv en værdi der højst er {0}."),
		min: $.validator.format("Angiv en værdi der mindst er {0}."),
		creditcard: "Indtast et gyldigt kreditkortnummer."
	});
}(jQuery));
var $mcj = jQuery.noConflict(true);</script>