{namespace neos=TYPO3\Neos\ViewHelpers}
{namespace media=TYPO3\Media\ViewHelpers}
<div class="col-lg-2 col-md-3 col-sm-4">
	<div class="team-1-member">
		<f:if condition="{image}">
			<f:then>
				<media:image asset="{image}" alt="Background Image" class="background-image" maximumWidth="172"
							 maximumHeight="172" allowCropping="1" allowUpScaling="1"/>
			</f:then>
			<f:else>
				<f:else>
					<f:security.ifAccess privilegeTarget="TYPO3.Neos:Backend.GeneralAccess">
						<f:if condition="{node.context.workspace.name} != 'live'">
							<img src="{f:uri.resource(package: 'MOC.Pivot', path: 'img/team-small-1.png')}"
								 title="Dummy image" alt="Dummy image"/>
						</f:if>
					</f:security.ifAccess>
				</f:else>
			</f:else>
		</f:if>
		{neos:contentElement.editable(property: 'title', tag: 'h5')}
		{neos:contentElement.editable(property: 'lead', tag: 'span')}<br>
		<ul class="social-icons">
			<f:if condition="{twitter}">
				<li>
					<a href="https://twitter.com/{twitter}">
						<i class="icon social_twitter"></i>
					</a>
				</li>
			</f:if>

			<f:if condition="{facebook}">
				<li>
					<a href="https://www.facebook.com/{facebook}">
						<i class="icon social_facebook"></i>
					</a>
				</li>
			</f:if>
			<f:if condition="{instagram}">
				<li>
					<a href="https://instagram.com/{instagram}">
						<i class="icon social_instagram"></i>
					</a>
				</li>
			</f:if>
			<f:if condition="{googlePlus}">
				<li>
					<a href="https://plus.google.com/+{googlePlus}">
						<i class="icon social_googleplus"></i>
					</a>
				</li>
			</f:if>
		</ul>
	</div>
</div>