{namespace neos=TYPO3\Neos\ViewHelpers}
<section class="pure-text-centered {backgroundColor}">
	<div class="container">
		<div class="row">
			<div class="col-sm-10 col-sm-offset-1 col-md-8 col-md-offset-2 text-center">
				{neos:contentElement.editable(property: 'intro', class: 'sub alt-font {fontColor}', tag: 'span')}
				{neos:contentElement.editable(property: 'title', class: '{fontColor}', tag: '{titleTag}')}
				{neos:contentElement.editable(property: 'text', class: 'lead {fontColor}', tag: 'p')}
			</div>
		</div>
	</div>
</section>