{namespace neos=TYPO3\Neos\ViewHelpers}
<div class="col-md-6 no-pad-left">
	<div class="feature feature-icon-left">
		<div class="icon-holder">
			<i class="icon {featureIcon}"></i>
		</div>
		<div class="feature-text">
			{neos:contentElement.editable(property: 'title', tag: 'h6')}
			{neos:contentElement.editable(property: 'lead', class: 'lead', tag: 'p')}
		</div>
	</div>
</div>