{namespace neos=TYPO3\Neos\ViewHelpers}
<div class="timeline-event">
	<div class="col-sm-6 {f:if(condition: switchText, else: ' col-md-push-6')}">
		{neos:contentElement.editable(property: 'year', tag: 'h2')}
		{neos:contentElement.editable(property: 'title', tag: 'h5')}
	</div>

	<div class="middle">
		<i class="icon {timelineIcon}"></i>
		<div class="vertical-line"></div>
	</div>

	<div class="col-sm-6 {f:if(condition: switchText, else: ' col-md-pull-6')}">
		{neos:contentElement.editable(property: 'lead', tag: 'p')}
	</div>
</div>