{namespace neos=TYPO3\Neos\ViewHelpers}
<footer class="details">
	<div class="container">
		<div class="row">
			<div class="col-sm-4">
				<img alt="logo" class="logo" src="{f:uri.resource(path: '{settings.logo}')}">
			</div>
			<div class="col-sm-4">
			</div>
			<div class="col-sm-4">
			</div>
		</div>
	</div>
</footer>
