{namespace neos=TYPO3\Neos\ViewHelpers}
<section class="pure-text">
	<div class="container">
		<div class="row">
			<div class="col-sm-10 col-sm-offset-1 col-md-8 col-md-offset-2">
				{neos:contentElement.editable(property: 'text')}
			</div>
		</div>
	</div>
</section>