{namespace neos=TYPO3\Neos\ViewHelpers}
{namespace media=TYPO3\Media\ViewHelpers}
<section>
	<div class="container">
		<div class="row">
			<div class="col-sm-6 text-center">
				<f:if condition="{featureImage.properties.image}">
					<f:then>
							<neos:contentElement.wrap node="{featureImage}">
								<figure>
									<media:image asset="{featureImage.properties.image}" class="phone-portrait" alt="App Screenshot" allowCropping="1" allowUpScaling="1"/>
								</figure>
							</neos:contentElement.wrap>
					</f:then>
					<f:else>
						<f:security.ifAccess privilegeTarget="TYPO3.Neos:Backend.GeneralAccess">
								<neos:contentElement.wrap node="{featureImage}">
									<figure>
										<f:if condition="{node.context.workspace.name} != 'live'">
											<img src="{f:uri.resource(package: 'TYPO3.Neos', path: 'Images/dummy-image.svg')}"
												 title="Dummy image" alt="Dummy image"/>
										</f:if>
									</figure>
								</neos:contentElement.wrap>
						</f:security.ifAccess>
					</f:else>
				</f:if>
			</div>

			<div class="col-sm-6 align-vertical no-align-mobile clearfix">
				{smallIconFeatures -> f:format.raw()}
			</div>
		</div>

	</div>
</section>