{namespace neos=TYPO3\Neos\ViewHelpers}
<section class="strip bg-primary">
	<div class="container">
		<div class="row clearfix">
			<form class="mail-list-signup" action="{newsletterSubscribeUrl}" method="post" id="mc-embedded-subscribe-form" name="mc-embedded-subscribe-form" class="validate" target="_blank" novalidate>
				<div style="position: absolute; left: -5000px;"><input type="text" name="b_efc05b2315776c785063ec547_00f746bba7" tabindex="-1" value=""></div>
				<div class="col-sm-9 col-xs-12 pull-left clear-fix">
					<label for="mce-EMAIL"><h3 class="text-white pull-left"><strong>Tilmeld dig vores nyhedsbrev</strong></h3></label>
					<input type="email" value="" name="EMAIL" class="signup-email-field validate-required validate-email" placeholder="Din email" id="mce-EMAIL">
				</div>
				<div class="col-sm-3 col-xs-12 pull-right text-right">
					<input type="submit" class="btn btn-primary btn-filled" name="subscribe" id="mc-embedded-subscribe" value="Abonnér">
				</div>
				<div id="mce-responses" class="clear col-sm-12">
					<div class="response" id="mce-error-response" style="display:none"></div>
					<div class="response" id="mce-success-response" style="display:none"></div>
				</div>    <!-- real people should not fill this in and expect good things - do not remove this or risk form bot signups-->
			</form>
		</div>
	</div>
</section>