{namespace neos=TYPO3\Neos\ViewHelpers}
<nav class="top-bar overlay-bar offscreen-menu">
	<div class="container">

		<div class="row nav-menu clearfix">
			<div class="col-xs-2">
				<neos:link.node node="~">
					<img class="logo logo-light" alt="Logo" src="{f:uri.resource(path: '{settings.logoLight}')}">
					<img class="logo logo-dark" alt="Logo" src="{f:uri.resource(path: '{settings.logoDark}')}">
				</neos:link.node>
			</div>

			<div class="col-xs-2 text-right pull-right">
				<div class="offscreen-toggle">
					<i class="icon icon_menu text-white"></i>
				</div>
			</div>
		</div>

		<div class="row">
			<div class="col-sm-12">
				<hr class="no-margin">
			</div>
		</div>

	</div>

	<div class="offscreen-container">
		<img class="logo logo-light" alt="Logo" src="{f:uri.resource(path: '{settings.logoLight}')}">
		{menu -> f:format.raw()}
		{socialIcons -> f:format.raw()}
	</div>
</nav>
