{namespace neos=TYPO3\Neos\ViewHelpers}
{namespace media=TYPO3\Media\ViewHelpers}
<section class="map-overlay">
	<div class="map-holder">
		<iframe src="{googleMaps}"></iframe>
	</div>
	<div class="container">
		<div class="row">
			<div class="col-md-4 col-md-offset-4 col-sm-6 col-sm-offset-3 text-center">
				<div class="details-holder">
					<div class="align-vertical">
						<f:if condition="{contactImage.properties.image}">
							<f:then>
									<neos:contentElement.wrap node="{contactImage}">
										<figure>
											<media:image asset="{contactImage.properties.image}" alt="{title}" title="{title}" maximumHeight="180" allowCropping="1" allowUpScaling="1"/>
										</figure>
									</neos:contentElement.wrap>
							</f:then>
							<f:else>
								<f:security.ifAccess privilegeTarget="TYPO3.Neos:Backend.GeneralAccess">
										<neos:contentElement.wrap node="{contactImage}">
											<figure>
												<f:if condition="{node.context.workspace.name} != 'live'">
													<img src="{f:uri.resource(package: 'TYPO3.Neos', path: 'Images/dummy-image.svg')}"
														 title="Dummy image" alt="Dummy image"/>
												</f:if>
											</figure>
										</neos:contentElement.wrap>
								</f:security.ifAccess>
							</f:else>
						</f:if>
						{neos:contentElement.editable(property: 'lead', class: 'lead', tag: 'p')}
						{neos:contentElement.editable(property: 'sublead', tag: 'p')}
					</div>
				</div>
			</div>
		</div>
	</div>
</section>
