{namespace neos=TYPO3\Neos\ViewHelpers}
{namespace media=TYPO3\Media\ViewHelpers}
<section class="video-inline">
	<div class="container">
		<div class="row">
			<div class="col-md-6 col-sm-12">
				{neos:contentElement.editable(property: 'title', class: 'space-bottom-medium', tag: 'h1')}
				{neos:contentElement.editable(property: 'lead', class: 'lead space-bottom-medium', tag: 'p')}
				<f:if condition="{link}">
					<{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a href="{link}"', else: 'span')}
					class="btn btn-primary">
					{neos:contentElement.editable(property: 'linkText')}
				</{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a', else: 'span')}>
				</f:if>
				<f:if condition="{link2}">
					<{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a href="{link2}"', else: 'span')}
					class="btn btn-primary btn-text-only">
					{neos:contentElement.editable(property: 'link2Text')}
				</{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a', else: 'span')}>
				</f:if>
			</div>

			<div class="col-md-6 col-sm-12">
				<div class="media-holder">
					<f:if condition="{youtube}">
						<iframe width="100%" height="315" frameborder="0" allowfullscreen=""
								src="http://www.youtube.com/embed/{youtube}?showinfo=0&amp;rel=0&amp;modestbranding=1">
						</iframe>
					</f:if>
					<f:if condition="{youtube} == ''">
						<f:if condition="{vimeo}">
							<iframe width="100%" height="315" frameborder="0" webkitallowfullscreen
									mozallowfullscreen allowfullscreen
									src="https://player.vimeo.com/video/{vimeo}?title=0&byline=0&portrait=0&badge=0">
							</iframe>
						</f:if>
					</f:if>
				</div>
			</div>
		</div>
	</div>
</section>
