{namespace neos=TYPO3\Neos\ViewHelpers}
<nav class="fullscreen-nav overlay-bar">
	<div class="container">
		<div class="row">
			<div class="col-sm-12">
				<neos:link.node node="~">
					<img class="outer-logo logo-light" alt="Logo" src="{f:uri.resource(path: '{settings.logoLight}')}">
				</neos:link.node>
			</div>
		</div>
	</div>

	<div class="fullscreen-nav-toggle">
		<i class="icon icon_menu"></i>
		<i class="icon icon_close"></i>
	</div>

	<div class="fullscreen-nav-container">
		<div class="container">
			<div class="row">
				<div class="col-sm-12">
					<neos:link.node node="~">
						<img class="logo" alt="Logo" src="{f:uri.resource(path: '{settings.logoLight}')}">
					</neos:link.node>
					{menu -> f:format.raw()}
				</div>
			</div>
		</div>
	</div>
</nav>