{namespace neos=TYPO3\Neos\ViewHelpers}
<div class="col-md-6 no-pad-left clearfix">
	<div class="feature feature-icon-small">
		<i class="icon {featureIcon}"></i>
		{neos:contentElement.editable(property: 'title', tag: 'h6')}
		{neos:contentElement.editable(property: 'text', tag: 'p')}
	</div>
</div>