{namespace neos=TYPO3\Neos\ViewHelpers}
<nav class="top-bar contained-bar">
	<div class="container">

		<div class="contained-wrapper">

			<div class="row nav-menu">
				<div class="col-md-2 col-sm-3 columns">
					<neos:link.node node="~">
						<img class="logo logo-light" alt="Logo" src="{f:uri.resource(path: '{settings.logoLight}')}">
						<img class="logo logo-dark" alt="Logo" src="{f:uri.resource(path: '{settings.logoDark}')}">
					</neos:link.node>
				</div>

				<div class="col-md-10 col-sm-9 columns">
					{menu -> f:format.raw()}
					{socialIcons -> f:format.raw()}
				</ul>
				</div>
			</div>

			<div class="mobile-toggle">
				<i class="icon icon_menu"></i>
			</div>

		</div>

	</div>
	<div class="bottom-border"></div>
</nav>
