{namespace neos=TYPO3\Neos\ViewHelpers}
{namespace media=TYPO3\Media\ViewHelpers}
<div class="col-sm-4 veo">
	<div class="image-holder" data-scroll-reveal="enter bottom and move 30px">
		<f:if condition="{image}">
			<f:then>
				<{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a href="{f:uri.resource(resource: image.resource)}"', else: 'span')} data-lightbox="true" data-title="{imageText}">
					<div class="background-image-holder">
						<media:image asset="{image}" alt="Gallery Image" class="background-image lightbox-image" allowCropping="0" allowUpScaling="1"/>
					</div>
			</{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a', else: 'span')}>
			</f:then>
			<f:else>
				<f:else>
					<f:security.ifAccess privilegeTarget="TYPO3.Neos:Backend.GeneralAccess">
						<f:if condition="{node.context.workspace.name} != 'live'">
							<img src="{f:uri.resource(package: 'TYPO3.Neos', path: 'Images/dummy-image.svg')}" title="Dummy image" class="center-block" alt="Dummy image"/>
						</f:if>
					</f:security.ifAccess>
				</f:else>
			</f:else>
		</f:if>

	</div>
</div>