{namespace neos=TYPO3\Neos\ViewHelpers}
<nav class="top-bar centered-logo">
	<div class="container">

		<div class="row utility-menu">
			<div class="col-sm-12">
				<div class="utility-inner clearfix">
					{utility -> f:format.raw()}
					{socialIcons -> f:format.raw()}
				</div>
			</div>
		</div>

		<div class="row">
			<div class="col-sm-12 text-center">
				<neos:link.node node="~">
					<img class="logo logo-light" alt="Logo" src="{f:uri.resource(path: '{settings.logoLight}')}">
					<img class="logo logo-dark" alt="Logo" src="{f:uri.resource(path: '{settings.logoDark}')}">
				</neos:link.node>
			</div>
		</div>


		<div class="row nav-menu">

			<div class="col-sm-12 columns text-center">
				{menu -> f:format.raw()}
			</div>
		</div>

		<div class="mobile-toggle">
			<i class="icon icon_menu"></i>
		</div>

	</div>
	<div class="bottom-border"></div>
</nav>
