{namespace neos=TYPO3\Neos\ViewHelpers}
<section>
	<div class="container">
		<div class="row">
			<div class="col-md-6 col-md-offset-3 col-sm-8 col-sm-offset-2 text-center">
				{neos:contentElement.editable(property: 'title', tag: 'h1')}
				{neos:contentElement.editable(property: 'lead', class: 'lead', tag: 'p')}
			</div>
		</div>

		<div class="row">
			<div class="image-gallery lightbox-gallery-mrv">
				{images -> f:format.raw()}
			</div>

		</div>
	</div>
</section>