if (typeof document.addEventListener === 'function') {
	document.addEventListener('Neos.PageLoaded', function(event) {
		$('.loader').css('opacity', 0);
		setTimeout(function(){$('.loader').hide();}, 600);
	}, false);
}