{namespace neos=TYPO3\Neos\ViewHelpers}
{namespace media=TYPO3\Media\ViewHelpers}
<section class="side-image clearfix">
	<div class="image-container col-md-5 col-sm-4 pull-left">
		<div class="background-image-holder">
			<f:if condition="{image}">
				<media:image asset="{image}" alt="Background Image" class="background-image" allowCropping="1" allowUpScaling="1" />
			</f:if>
		</div>
	</div>

	<div class="container">
		<div class="row">
			<div class="col-md-6 col-md-offset-6 col-sm-7 col-sm-offset-5 content clearfix">
				{neos:contentElement.editable(property: 'title', tag: 'h1')}
				{neos:contentElement.editable(property: 'lead', class: 'lead', tag: 'p')}

				{imageFeatures -> f:format.raw()}
			</div>
		</div>
	</div>
</section>
