{namespace neos=TYPO3\Neos\ViewHelpers}
{namespace media=TYPO3\Media\ViewHelpers}
<header class="fullscreen-element no-pad centered-text {backgroundColor}">
	<div class="background-image-holder parallax-background overlay">
		<f:if condition="{image}">
			<media:image asset="{image}" alt="Background Image" class="background-image" maximumWidth="2000" maximumHeight="1500" allowCropping="1" allowUpScaling="1" />
		</f:if>
	</div>

	<div class="container align-vertical">
		<div class="row">
			<div class="col-md-12 text-center">
				{neos:contentElement.editable(property: 'intro', class: 'alt-font {fontColor}', tag: 'span')}
				{neos:contentElement.editable(property: 'title', class: '{fontColor}', tag: '{titleTag}')}
				{neos:contentElement.editable(property: 'lead', class: 'lead {fontColor}')}
				<f:if condition="{link}">
					<{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a href="{link}"', else: 'span')} class="btn btn-primary btn-white">
						{neos:contentElement.editable(property: 'linkText')}
					</{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a', else: 'span')}>
				</f:if>
				<f:if condition="{link2}">
					<{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a href="{link2}"', else: 'span')} class="btn btn-primary btn-white">
						{neos:contentElement.editable(property: 'link2Text')}
					</{f:if(condition: '{node.context.workspaceName} == "live"', then: 'a', else: 'span')}>
				</f:if>
			</div>
		</div>
	</div>
</header>