{namespace neos=TYPO3\Neos\ViewHelpers}
<section class="video-inline">
	<div class="container">
		<div class="row">
			<div class="col-md-8 col-md-offset-2 col-sm-10 col-sm-offset-1 text-center">
				{neos:contentElement.editable(property: 'title', class: 'space-bottom-medium', tag: 'h1')}
				{neos:contentElement.editable(property: 'lead', class: 'lead space-bottom-medium', tag: 'p')}
			</div>
		</div>

		<div class="row">
			<div class="col-sm-12">
				<div class="media-holder fullwidth-video">
					<f:if condition="{youtube}">
						<f:then>
							<iframe width="100%" height="315" frameborder="0" allowfullscreen=""
									src="http://www.youtube.com/embed/{youtube}?showinfo=0&amp;rel=0&amp;modestbranding=1">

							</iframe>
						</f:then>
						<f:else>
							<f:if condition="{vimeo}">
								<iframe width="100%" height="315" frameborder="0" webkitallowfullscreen
										mozallowfullscreen allowfullscreen
										src="https://player.vimeo.com/video/{vimeo}?title=0&byline=0&portrait=0&badge=0"></iframe>
							</f:if>
						</f:else>
					</f:if>
				</div>
			</div>
		</div>
	</div>
</section>